Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetRandomizedOption ¶
func GetRandomizedOption(excludeFromList string) googlesearch.SearchOptions
func GetResultSetCounts ¶
func PrintResultSetPreview ¶
func PrintResultSetPreview(results []ResultSet)
Types ¶
type ResultSet ¶
type ResultSet struct {
//Query:
// - The querystring utilized
Query string `json:"query"`
//Results:
// - A slice of "Result" type from google-search package
Results []googlesearch.Result `json:"results"`
}
func SearchMultiple ¶
type SearchParameters ¶
type SearchParameters struct {
//Aggression:
// - How quickly/aggressive the search wrapper should function.
// - Options are "H","M","L", but can be left blank. See randomization.go for more info
Aggression string `json:"aggression"`
//MaxResults:
// - How many search results should be returned per query
// - Passed through to google-search option
// - Default is 30
MaxResults int `json:"max_results"`
//CountryCode:
// - Passed through to google-search
// - Helps identify which Google domain to utilize
// - google-search sets "us" as default
CountryCode string `json:"country_code"`
//MaxRetries:
// - If blocked by Google, how many times tp keep trying before giving up
// - Default is 10 retries
MaxRetries int `json:"max_retries"`
//BlkStartWait:
// - When blocked by Google, the base number of seconds to wait before trying again
// - Default is 60 seconds
BlkStartWait int `json:"block_start_wait_seconds"`
//BlkInc:
// - When blocked by Google, the number of seconds added to the wait time
// - Default is 30 seconds
BlkInc int `json:"block_increment_seconds"`
}
Click to show internal directories.
Click to hide internal directories.